@@ -35,10 +35,6 @@ sub scan {
     }
     return undef if $match < 0;
 
-    require Sisimai::MIME;
-    require Sisimai::String;
-    require Sisimai::Address;
-
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
     my @hasdivided = split("\n", $$mbody);
     my $rfc822part = '';    # (String) message/rfc822-headers part
@@ -67,7 +63,7 @@ sub scan {
         };
 
         $boundary00 = Sisimai::MIME->boundary($mhead->{'content-type'});
-        if( length $boundary00 ) {
+        if( $boundary00 ) {
             # Convert to regular expression
             $boundary00 = '--'.$boundary00.'--';
             $MarkingsOf->{'rfc822'} = qr/\A\Q$boundary00\E\z/; 
@@ -113,7 +109,7 @@ sub scan {
                 $v = $dscontents->[-1];
 
                 if( $e =~ /\A[ \t]+RCPT TO: (.*)\z/ ) {
-                    if( length $v->{'recipient'} ) {
+                    if( $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
                         push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                         $v = $dscontents->[-1];
@@ -143,7 +139,7 @@ sub scan {
         $MessagesOf = { 'userunknown' => ['No valid recipients for this MM'] };
 
         $boundary00 = Sisimai::MIME->boundary($mhead->{'content-type'});
-        if( length $boundary00 ) {
+        if( $boundary00 ) {
             # Convert to regular expression
             $boundary00 = '--'.$boundary00.'--';
             $MarkingsOf->{'rfc822'} = qr/\A\Q$boundary00\E\z/; 
@@ -189,7 +185,7 @@ sub scan {
                 $v = $dscontents->[-1];
 
                 if( $e =~ /\ATo:[ \t]+(.*)\z/ ) {
-                    if( length $v->{'recipient'} ) {
+                    if( $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
                         push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                         $v = $dscontents->[-1];
